//=========================================================================================
//#include "types.h"

//-----------------------------------------------------------------------------
// FAT32 File Attributes and Types
//-----------------------------------------------------------------------------
#define FILE_ATTR_READ_ONLY     0x01
#define FILE_ATTR_HIDDEN        0x02
#define FILE_ATTR_SYSTEM        0x04
#define FILE_ATTR_SYSHID        0x06
#define FILE_ATTR_VOLUME_ID     0x08
#define FILE_ATTR_DIRECTORY     0x10
#define FILE_ATTR_ARCHIVE       0x20
#define FILE_ATTR_LFN_TEXT      0x0F
#define FILE_ATTR_LFN_MASK      0x3F
#define FILE_HEADER_BLANK       0x00
#define FILE_HEADER_DELETED     0xE5
#define FILE_TYPE_DIR           0x10
#define FILE_TYPE_FILE          0x20
#define FILE_TYPE_MP3           0x55
#define FAT16_LDIR_Ord          0
#define FAT16_LDIR_Name1        1
#define FAT16_LDIR_Attr         11
#define FAT16_LDIR_Type         12
#define FAT16_LDIR_Chksum       13
#define FAT16_LDIR_Name2        14
#define FAT16_LDIR_FstClusLO    26
#define FAT16_LDIR_Name3        28

//---------------------------------------------------------------------------------
// Partition Type used in the partition record
//---------------------------------------------------------------------------------
#define PART_TYPE_UNKNOWN		0x00
#define PART_TYPE_FAT12			0x01
#define PART_TYPE_XENIX			0x02
#define PART_TYPE_DOSFAT16		0x04
#define PART_TYPE_EXTDOS		0x05
#define PART_TYPE_FAT16			0x06
#define PART_TYPE_NTFS			0x07
#define PART_TYPE_FAT32			0x0B
#define PART_TYPE_FAT32LBA		0x0C
#define PART_TYPE_FAT16LBA		0x0E
#define PART_TYPE_EXTDOSLBA		0x0F
#define PART_TYPE_ONTRACK		0x33
#define PART_TYPE_NOVELL		0x40
#define PART_TYPE_PCIX			0x4B
#define PART_TYPE_PHOENIXSAVE   	0xA0
#define PART_TYPE_CPM			0xDB
#define PART_TYPE_DBFS			0xE0
#define PART_TYPE_BBT			0xFF


unsigned char SectorBuffer [512]; //    
unsigned long Fat2Cluster; //         FAT  

//***********************************************   MBR (Master Boot Record) **************************************************
#define PARTITION_START 446 //  (446 )   MSB   0 (     1)
unsigned char MBR_FAT_filetype; //    (    ( 0) -  446 + 04h)
unsigned long MBR_sector_BIOS_PB; //  ()    ( 0) -  446 + 08h)

//***********************************************   BPB (BIOS Parameter Block) ************************************************
unsigned long BPB_SectSize; //     (  BIOS PB -  0Bh)[  512]
unsigned char BPB_ClustSize;//     (  BIOS PB -  ODh)
unsigned long BPB_ResSect;  //     FAT#1 (  BIOS PB -  0Eh)
unsigned char BPB_FatCnt;   // -  FAT   (  BIOS PB -  10h)[  2]
unsigned long BPB_RootSize; //  32-    (  BIOS PB -  11h)( FAT16   512)
unsigned long BPB_FatSize;  //     FAT (  BIOS PB -  16h)
//*************************************************************************************************************************************

//**********************************************   *******************************************************************
unsigned long FAT_begin; //  FAT (  )
unsigned long Root_dir_begin; //    (  )
unsigned long Data_begin; //    ( 2)
// *************************************************************************************************************************************

unsigned char FAT_init(void);      //  MBR, BPB         
unsigned char ReadCluster(unsigned long);  //   (. -    )
unsigned long NextCluster (unsigned long); //       FAT (. -    )

